@@ -10,3 +10,5 @@ lipids_processing = ProcessingProfile(name="Lipids", aliquot_type=wb)
 poc_processing = ProcessingProfile(name="POC", aliquot_type=disposable)
 rft_processing = ProcessingProfile(name="RFT", aliquot_type=wb)
 sputum_processing = ProcessingProfile(name="Sputum", aliquot_type=sputum)
+vl_processing = ProcessingProfile(name="Viral load", aliquot_type=wb)
+cd4_processing = ProcessingProfile(name="CD4", aliquot_type=wb)
